==> plasma-workspace-6.2.91.tar.xz: plasma-workspace-6.2.91/plasma-windowed/org.kde.plasmawindowed.desktop.cmake <==
[Desktop Entry]
Name=Plasma Windowed
Name[ar]=بلازما المؤطرة
Name[az]=Pəncərədə Plasma
Name[be]=Плазмоіды як праграмы
Name[bg]=Plasma уиджети в самостоятелен прозорец
Name[bs]=Plazma uprozorena
Name[ca]=Plasma amb finestres
Name[ca@valencia]=Plasma amb finestres
Name[cs]=Plasma v okně
Name[da]=Plasma i vinduestilstand
Name[de]=Plasma-Fenster
Name[el]=Plasma σε παράθυρα
Name[en_GB]=Plasma Windowed
Name[eo]=Plasma Enfenestra
Name[es]=Plasma en ventanas
Name[et]=Akendesse paigutatud Plasma
Name[eu]=Plasma leihoetan
Name[fi]=Ikkunoitu Plasma
Name[fr]=Plasma fenêtré
Name[gl]=Plasma en xanelas
Name[he]=פלזמה בחלונות
Name[hi]=प्लाज़्मा विंडोड
Name[hu]=Ablakban futtatott plazma
Name[ia]=Plasma Windowed (in fenestras)
Name[id]=Perjendelaan Plasma
Name[is]=Plasma í gluggum
Name[it]=Plasma a finestre
Name[ja]=ウインドウ化された Plasma
Name[ka]=Plasma ფანჯარაში
Name[ko]=창 모드 Plasma
Name[lt]=Languota Plasma
Name[lv]=Plasma Windowed
Name[ml]=പ്ലാസ്മ ജാലകീകരിച്ചത്
Name[nb]=Plasma i vindu
Name[nds]=Plasma-Finstern
Name[nl]=Plasma weergegeven in vensters
Name[nn]=Plasma i vindauge
Name[pa]=ਪਲਾਜ਼ਮਾ ਵਿੰਡੋ
Name[pl]=Okienkowa Plazma
Name[pt]=Plasma em Janelas
Name[pt_BR]=Plasma em janelas
Name[ro]=Plasma în fereastră
Name[ru]=Plasma в окне
Name[sa]=प्लाज्मा गवाक्षयुक्त
Name[sk]=Plasma v okne
Name[sl]=Okenski način Plasma
Name[sr]=Плазма у прозору
Name[sr@ijekavian]=Плазма у прозору
Name[sr@ijekavianlatin]=Plasma u prozoru
Name[sr@latin]=Plasma u prozoru
Name[sv]=Plasma i fönster
Name[ta]=சாளர பிளாஸ்மாய்டுகள்
Name[tr]=Plasma Penceresi
Name[uk]=Плазма у вікні
Name[vi]=Plasma cửa sổ hoá
Name[x-test]=xxPlasma Windowedxx
Name[zh_CN]=窗口化 Plasma
Name[zh_TW]=Plasma 視窗
Comment=Run Plasmoids as simple applications
Comment[ar]=شغل بلازمويد كتطبيق بسيط
Comment[az]=Plasma əlavəsini adi tətbiq kimi başlatmaq
Comment[be]=Запуск плазмоідаў як простых праграм
Comment[bg]=Стартиране на уиджетите на Plasma като прости приложения
Comment[bs]=Pokreni plazmoide kao običnu aplikaciju
Comment[ca]=Executa els plasmoides com a simples aplicacions
Comment[ca@valencia]=Executa els plasmoides com a simples aplicacions
Comment[cs]=Spouštějte Plasmoidy jako prosté aplikace
Comment[da]=Kør plasmoids som simple programmer
Comment[de]=Ausführung von Plasmoiden als einfache Anwendungen
Comment[el]=Εκτέλεση των πλασμοειδών ως απλές εφαρμογές
Comment[en_GB]=Run Plasmoids as simple applications
Comment[eo]=Ruligi Plasmoidojn kiel simplaj aplikaĵoj
Comment[es]=Ejecutar plasmoides como aplicaciones simples
Comment[et]=Plasmoidide käivitamine tavaliste rakendustena
Comment[eu]=Exekutatu Plasmoideak aplikazio arrunt gisa
Comment[fi]=Suorita plasmoideja sovelluksina
Comment[fr]=Lancer les plasmoïdes comme de simples applications
Comment[gl]=Executar trebellos como aplicacións sinxelas.
Comment[he]=הצגת Plasmoids כיישומים פשוטים
Comment[hi]=प्लाज़्मोइड को सरल अनुप्रयोगों के रूप में चलाएँ
Comment[hu]=Plasmoidok futtatása egyszerű alkalmazásként
Comment[ia]=Executa Plasmoids como applicationes simple
Comment[id]=Menjalankan Plasmoids sebagai aplikasi sederhana
Comment[is]=Keyra Plasma-græjur sem einföld forrit
Comment[it]=Esegui i plasmoidi come semplici applicazioni
Comment[ja]=Plasmoid を単純なアプリケーションとして実行
Comment[ka]=პლაზმოიდების ცალკე აპლიკაციებად გაშვება
Comment[ko]=Plasmoid를 간단한 앱으로 실행
Comment[lt]=Paleisti Plasma įskiepius kaip paprastas programas
Comment[lv]=Palaist plazmoīdus kā vienkāršas programmas
Comment[ml]=ലളിതമായ ആപ്ലിക്കേഷനുകളായി പ്ലാസ്മോയിഡുകൾ പ്രവർത്തിപ്പിക്കുക
Comment[nb]=Kjør plasmoider som enkle programmer
Comment[nds]=Plasma-Lüttprogrammen as eenfach Programmen utföhren
Comment[nl]=Plasmoids uitvoeren als eenvoudige toepassingen
Comment[nn]=Køyr skjermelement som enkle program
Comment[pa]=ਪਲਾਜ਼ਮੋਡ ਨੂੰ ਸਰਲ ਐਪਲੀਕੇਸ਼ਨਾਂ ਵਜੋਂ ਚਲਾਓ
Comment[pl]=Uruchamia Plazmoidy jako proste aplikacje
Comment[pt]=Executar os plasmóides como aplicações simples
Comment[pt_BR]=Executa os plasmoides como aplicativos simples
Comment[ro]=Rulează plasmoizi ca simple aplicații
Comment[ru]=Запуск виджетов Plasma в качестве оконных приложений
Comment[sa]=प्लाज्मोइड्स् सरल-अनुप्रयोगरूपेण चालयन्तु
Comment[sk]=Spúšťať Plazmoidy ako jednoduché aplikácie
Comment[sl]=Zaganjajte Plasmoide kot preproste programe
Comment[sr]=Извршавање плазмоида као простих програма
Comment[sr@ijekavian]=Извршавање плазмоида као простих програма
Comment[sr@ijekavianlatin]=Izvršavanje plazmoida kao prostih programa
Comment[sr@latin]=Izvršavanje plazmoida kao prostih programa
Comment[sv]=Kör Plasmoider som enkla program
Comment[ta]=பிளாஸ்மாய்டுகளை தனிப்பட்ட செயலிகளாக இயக்கும்
Comment[tr]=Plasmoid’leri basit uygulamalar olarak çalıştırın
Comment[uk]=Запуск плазмоїдів як простих програм
Comment[vi]=Chạy các Plasmoid như các ứng dụng đơn giản
Comment[x-test]=xxRun Plasmoids as simple applicationsxx
Comment[zh_CN]=将小部件当作简单应用程序运行
Comment[zh_TW]=以簡單應用程式執行 Plasma 小元件

Exec=@CMAKE_INSTALL_PREFIX@/bin/plasmawindowed
Terminal=false
NoDisplay=true
Icon=plasma
Type=Application
X-DBUS-StartupType=Unique
InitialPreference=1
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management,org_kde_kwin_keystate,zkde_screencast_unstable_v1,org_kde_plasma_activation_feedback

==> plasma-workspace-6.3.3.tar.xz: plasma-workspace-6.3.3/plasma-windowed/org.kde.plasmawindowed.desktop.cmake <==
[Desktop Entry]
Name=Plasma Windowed
Name[ar]=بلازما المؤطرة
Name[az]=Pəncərədə Plasma
Name[be]=Плазмоіды як праграмы
Name[bg]=Plasma уиджети в самостоятелен прозорец
Name[bs]=Plazma uprozorena
Name[ca]=Plasma amb finestres
Name[ca@valencia]=Plasma amb finestres
Name[cs]=Plasma v okně
Name[da]=Plasma i vinduestilstand
Name[de]=Plasma-Fenster
Name[el]=Plasma σε παράθυρα
Name[en_GB]=Plasma Windowed
Name[eo]=Plasma Enfenestra
Name[es]=Plasma en ventanas
Name[et]=Akendesse paigutatud Plasma
Name[eu]=Plasma leihoetan
Name[fi]=Ikkunoitu Plasma
Name[fr]=Plasma fenêtré
Name[gl]=Plasma en xanelas
Name[he]=פלזמה בחלונות
Name[hi]=प्लाज़्मा विंडोड
Name[hu]=Ablakban futtatott plazma
Name[ia]=Plasma Windowed (in fenestras)
Name[id]=Perjendelaan Plasma
Name[is]=Plasma í gluggum
Name[it]=Plasma a finestre
Name[ja]=ウインドウ化された Plasma
Name[ka]=Plasma ფანჯარაში
Name[ko]=창 모드 Plasma
Name[lt]=Languota Plasma
Name[lv]=Plasma Windowed
Name[ml]=പ്ലാസ്മ ജാലകീകരിച്ചത്
Name[nb]=Plasma i vindu
Name[nds]=Plasma-Finstern
Name[nl]=Plasma weergegeven in vensters
Name[nn]=Plasma i vindauge
Name[pa]=ਪਲਾਜ਼ਮਾ ਵਿੰਡੋ
Name[pl]=Okienkowa Plazma
Name[pt]=Plasma em Janelas
Name[pt_BR]=Plasma em janelas
Name[ro]=Plasma în fereastră
Name[ru]=Plasma в окне
Name[sa]=प्लाज्मा गवाक्षयुक्त
Name[sk]=Plasma v okne
Name[sl]=Okenski način Plasma
Name[sr]=Плазма у прозору
Name[sr@ijekavian]=Плазма у прозору
Name[sr@ijekavianlatin]=Plasma u prozoru
Name[sr@latin]=Plasma u prozoru
Name[sv]=Plasma i fönster
Name[ta]=சாளர பிளாஸ்மாய்டுகள்
Name[tr]=Plasma Penceresi
Name[uk]=Плазма у вікні
Name[vi]=Plasma cửa sổ hoá
Name[x-test]=xxPlasma Windowedxx
Name[zh_CN]=窗口化 Plasma
Name[zh_TW]=Plasma 視窗
Comment=Run Plasmoids as simple applications
Comment[ar]=شغل بلازمويد كتطبيق بسيط
Comment[az]=Plasma əlavəsini adi tətbiq kimi başlatmaq
Comment[be]=Запуск плазмоідаў як простых праграм
Comment[bg]=Стартиране на уиджетите на Plasma като прости приложения
Comment[bs]=Pokreni plazmoide kao običnu aplikaciju
Comment[ca]=Executa els plasmoides com a simples aplicacions
Comment[ca@valencia]=Executa els plasmoides com a simples aplicacions
Comment[cs]=Spouštějte Plasmoidy jako prosté aplikace
Comment[da]=Kør plasmoids som simple programmer
Comment[de]=Ausführung von Plasmoiden als einfache Anwendungen
Comment[el]=Εκτέλεση των πλασμοειδών ως απλές εφαρμογές
Comment[en_GB]=Run Plasmoids as simple applications
Comment[eo]=Ruligi Plasmoidojn kiel simplaj aplikaĵoj
Comment[es]=Ejecutar plasmoides como aplicaciones simples
Comment[et]=Plasmoidide käivitamine tavaliste rakendustena
Comment[eu]=Exekutatu Plasmoideak aplikazio arrunt gisa
Comment[fi]=Suorita plasmoideja sovelluksina
Comment[fr]=Lancer les plasmoïdes comme de simples applications
Comment[gl]=Executar trebellos como aplicacións sinxelas.
Comment[he]=הצגת Plasmoids כיישומים פשוטים
Comment[hi]=प्लाज़्मोइड को सरल अनुप्रयोगों के रूप में चलाएँ
Comment[hu]=Plasmoidok futtatása egyszerű alkalmazásként
Comment[ia]=Executa Plasmoids como applicationes simple
Comment[id]=Menjalankan Plasmoids sebagai aplikasi sederhana
Comment[is]=Keyra Plasma-græjur sem einföld forrit
Comment[it]=Esegui i plasmoidi come semplici applicazioni
Comment[ja]=Plasmoid を単純なアプリケーションとして実行
Comment[ka]=პლაზმოიდების ცალკე აპლიკაციებად გაშვება
Comment[ko]=Plasmoid를 간단한 앱으로 실행
Comment[lt]=Paleisti Plasma įskiepius kaip paprastas programas
Comment[lv]=Palaist plazmoīdus kā vienkāršas programmas
Comment[ml]=ലളിതമായ ആപ്ലിക്കേഷനുകളായി പ്ലാസ്മോയിഡുകൾ പ്രവർത്തിപ്പിക്കുക
Comment[nb]=Kjør skjermelement som enkle programmer
Comment[nds]=Plasma-Lüttprogrammen as eenfach Programmen utföhren
Comment[nl]=Plasmoids uitvoeren als eenvoudige toepassingen
Comment[nn]=Køyr skjermelement som enkle program
Comment[pa]=ਪਲਾਜ਼ਮੋਡ ਨੂੰ ਸਰਲ ਐਪਲੀਕੇਸ਼ਨਾਂ ਵਜੋਂ ਚਲਾਓ
Comment[pl]=Uruchamia Plazmoidy jako proste aplikacje
Comment[pt]=Executar os plasmóides como aplicações simples
Comment[pt_BR]=Executa os plasmoides como aplicativos simples
Comment[ro]=Rulează plasmoizi ca simple aplicații
Comment[ru]=Запуск виджетов Plasma в качестве оконных приложений
Comment[sa]=प्लाज्मोइड्स् सरल-अनुप्रयोगरूपेण चालयन्तु
Comment[sk]=Spúšťať Plazmoidy ako jednoduché aplikácie
Comment[sl]=Zaganjajte Plasmoide kot preproste programe
Comment[sr]=Извршавање плазмоида као простих програма
Comment[sr@ijekavian]=Извршавање плазмоида као простих програма
Comment[sr@ijekavianlatin]=Izvršavanje plazmoida kao prostih programa
Comment[sr@latin]=Izvršavanje plazmoida kao prostih programa
Comment[sv]=Kör Plasmoider som enkla program
Comment[ta]=பிளாஸ்மாய்டுகளை தனிப்பட்ட செயலிகளாக இயக்கும்
Comment[tr]=Plasmoid’leri basit uygulamalar olarak çalıştırın
Comment[uk]=Запуск плазмоїдів як простих програм
Comment[vi]=Chạy các Plasmoid như các ứng dụng đơn giản
Comment[x-test]=xxRun Plasmoids as simple applicationsxx
Comment[zh_CN]=将小部件当作简单应用程序运行
Comment[zh_TW]=以簡單應用程式執行 Plasma 小元件

Exec=@CMAKE_INSTALL_PREFIX@/bin/plasmawindowed
Terminal=false
NoDisplay=true
Icon=plasma
Type=Application
X-DBUS-StartupType=Unique
InitialPreference=1
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management,org_kde_kwin_keystate,zkde_screencast_unstable_v1,org_kde_plasma_activation_feedback
